diff --git a/modules/toolbar/toolbar.js b/modules/toolbar/toolbar.js
index 5b61634..c4576b3 100644
--- a/modules/toolbar/toolbar.js
+++ b/modules/toolbar/toolbar.js
@@ -7,17 +7,24 @@ Drupal.toolbar = Drupal.toolbar || {};
  */
 Drupal.behaviors.toolbar = {
   attach: function(context) {
-
-    // Set the initial state of the toolbar.
-    $('#toolbar', context).once('toolbar', Drupal.toolbar.init);
-
-    // Toggling toolbar drawer.
-    $('#toolbar a.toggle', context).once('toolbar-toggle').click(function(e) {
-      Drupal.toolbar.toggle();
-      // Allow resize event handlers to recalculate sizes/positions.
-      $(window).triggerHandler('resize');
-      return false;
-    });
+    // Only attach functionality if drawer has children.
+    if ($('#toolbar div.toolbar-drawer').children().size() == 0) {
+    // Remove toggle button, drawer and arrange toolbar padding.
+      $('#toolbar a.toggle').remove();
+      $('#toolbar div.toolbar-drawer').remove();
+      $('#toolbar div.toolbar-menu').css('paddingRight', $('#toolbar div.toolbar-menu').css('paddingLeft'));
+    }
+    else {
+      // Set the initial state of the toolbar.
+      $('#toolbar', context).once('toolbar', Drupal.toolbar.init);
+      // Toggling toolbar drawer.
+      $('#toolbar a.toggle', context).once('toolbar-toggle').click(function(e) {
+        Drupal.toolbar.toggle();
+        // Allow resize event handlers to recalculate sizes/positions.
+        $(window).triggerHandler('resize');
+        return false;
+      });
+    }
   }
 };
 
